
=============================
Leonardo leonardo-sitestarter
=============================

Simple leonardo module which is composed from tools for generating Leonardo Sites from templates declared in yaml or json localy or on remote storage

.. contents::
    :local:

Installation
------------

.. code-block:: bash

    pip install leonardo-sitestarter

Read More
=========

* https://github.com/django-leonardo/django-leonardo
